@@ -44,7 +44,7 @@ def histplot(
     edges=True,
     binticks=False,
     ax=None,
-    **kwargs
+    **kwargs,
 ):
     """
     Create a 1D histogram plot from `np.histogram`-like inputs.
@@ -107,7 +107,7 @@ def histplot(
 
     # arg check
     _allowed_histtype = ["fill", "step", "errorbar"]
-    _err_message = "Select 'histtype' from: {}".format(_allowed_histtype)
+    _err_message = f"Select 'histtype' from: {_allowed_histtype}"
     assert histtype in _allowed_histtype, _err_message
 
     def hist_object_handler(h, check_only=False):
@@ -262,53 +262,7 @@ def histplot(
     else:
         _yerr = None
 
-    ############################
-    # Stacking, norming, density
-    def get_stack(_h):
-        if NH > 1:
-            return np.cumsum(_h, axis=0)
-        else:
-            return _h
-
-    def get_density(h, density=True, binwnorm=None, bins=bins):
-        assert (not density) ^ (
-            binwnorm is None
-        ), "Can only calculate density or binwnorm"
-        per_hist_norm = np.sum(h, axis=1 if NH > 1 else 0)
-        if binwnorm is not None:
-            overallnorm = binwnorm * per_hist_norm
-        else:
-            overallnorm = np.ones(NH)
-        binnorms = np.outer(overallnorm, np.ones_like(bins[:-1]))
-        binnorms /= np.outer(np.diff(bins), per_hist_norm).T
-        if binnorms.ndim == 2 and len(binnorms) == 1:  # Unwrap if [[1,2,3]]
-            binnorms = binnorms[0]
-        return binnorms
-
-    if density or binwnorm is not None:
-        density_arr = get_density(h, density, binwnorm)
-        if stack:
-            h = get_stack(h)
-            h *= get_density(h, density, binwnorm)[-1]
-        else:
-            h *= density_arr
-        if _yerr is not None:
-            for i in range(len(density_arr)):
-                _yerr[i] = _yerr[i] * density_arr[i]
-
-    if stack and not density and binwnorm is None:
-        h = get_stack(h)
-
-    # Stack
-    if stack and NH > 1:
-        h = h[::-1]
-        _labels = _labels[::-1]
-        _chunked_kwargs = _chunked_kwargs[::-1]
-
-    #################################
-    # Split and reshape for iteration
-    h = h.reshape(NH, -1)
-    if yerr is not None:
+    if _yerr is not None:
         if _yerr.ndim == 3:
             # Already correct format
             pass
@@ -332,6 +286,54 @@ def histplot(
         _yerr_lo = _yerr[:, 0]
         _yerr_hi = _yerr[:, 1]
 
+    ############################
+    # Stacking, norming, density
+    def get_stack(_h):
+        if NH > 1:
+            return np.cumsum(_h, axis=0)
+        else:
+            return _h
+
+    def get_density(h, density=True, binwnorm=None, bins=bins):
+        assert (not density) ^ (
+            binwnorm is None
+        ), "Can only calculate density or binwnorm"
+        per_hist_norm = np.sum(h, axis=(1 if h.ndim > 1 else 0))
+        if binwnorm is not None:
+            overallnorm = binwnorm * per_hist_norm
+        else:
+            overallnorm = np.ones(NH)
+        binnorms = np.outer(overallnorm, np.ones_like(bins[:-1]))
+        binnorms /= np.outer(np.diff(bins), per_hist_norm).T
+        if binnorms.ndim == 2 and len(binnorms) == 1:  # Unwrap if [[1,2,3]]
+            binnorms = binnorms[0]
+        return binnorms
+
+    if density or binwnorm is not None:
+        density_arr = get_density(h, density, binwnorm)
+        if stack:
+            h = get_stack(h)
+            h *= get_density(h, density, binwnorm)[-1]
+        else:
+            h *= density_arr
+        if _yerr is not None:
+            for i in range(NH):
+                _yerr_lo[i] = _yerr_lo[i] * density_arr[i]
+                _yerr_hi[i] = _yerr_hi[i] * density_arr[i]
+
+    if stack and not density and binwnorm is None:
+        h = get_stack(h)
+
+    # Stack
+    if stack and NH > 1:
+        h = h[::-1]
+        _labels = _labels[::-1]
+        _chunked_kwargs = _chunked_kwargs[::-1]
+
+    #################################
+    # Split and reshape for iteration
+    h = h.reshape(NH, -1)
+
     ##########
     # Plotting
     return_artists = []
@@ -356,7 +358,7 @@ def histplot(
                     h[i],
                     yerr=[_yerr_lo[i], _yerr_hi[i]],
                     linestyle="none",
-                    **_kwargs
+                    **_kwargs,
                 )
                 _eleg = ax.errorbar(
                     [], [], yerr=1, xerr=1, color=_s.get_color(), label=_label
@@ -427,7 +429,7 @@ def hist2dplot(
     cmin=None,
     cmax=None,
     ax=None,
-    **kwargs
+    **kwargs,
 ):
     """
     Create a 2D histogram plot from `np.histogram`-like inputs.
@@ -548,10 +550,10 @@ def hist2dplot(
     plt.sca(ax)
 
     if labels is not None:
-        if np.array_equiv(H, labels):
-            _labels = labels
-        elif labels is True:
+        if labels is True:
             _labels = H
+        elif H.shape == labels.shape:
+            _labels = labels
         elif labels is False:
             pass
         else:
